@@ -6,8 +6,8 @@ import java.util.ArrayList;
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 
-import aligner.MicroAligner;
-import aligner.SingleStateAlignerFlat2;
+import aligner.MicroAligner3;
+import aligner.MicroIndex3;
 import barcode.BarcodeStats;
 import bloom.BloomFilter;
 import bloom.BloomFilterCorrector;
@@ -21,22 +21,18 @@ import jgi.Dedupe;
 import kmer.AbstractKmerTable;
 import kmer.HashArray1D;
 import kmer.ScheduleMaker;
-import prok.GeneCaller;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
-import stream.ConcurrentGenericReadInputStream;
 import stream.ConcurrentReadInputStream;
 import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
-import structures.ByteBuilder;
 import structures.IntList;
 import structures.ListNum;
-import structures.LongHashMap;
 import structures.LongList;
 import template.Accumulator;
 import template.ThreadWaiter;
@@ -118,7 +114,9 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 			}else if(a.equals("loadkmers") || a.equals("usekmers")){
 				loadKmers=Parse.parseBoolean(b);
 			}else if(a.equals("allkmers")){
-				allKmers=Parse.parseBoolean(b);
+				kmersPerRead=(Parse.parseBoolean(b) ? 0 : 1);
+			}else if(a.equals("kmersperread")){
+				kmersPerRead=Integer.parseInt(b);
 			}else if(a.equals("multithreaded")){
 				multithreadedLoad=multithreadedFill=Parse.parseBoolean(b);
 			}else if(a.equals("multiload")){
@@ -136,6 +134,8 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 			}else if(a.equals("minid")){
 				minIdentity=Float.parseFloat(b);
 				if(minIdentity>1) {minIdentity/=100;}
+			}else if(a.equals("kalign") || a.equals("alignk")){
+				alignK=Integer.parseInt(b);
 			}else if(a.equals("expectedbarcodes") || a.equals("expected") || a.equals("barcodes")){
 				expectedBarcodes=b;
 			}else if(a.equals("shortheader")){
@@ -187,7 +187,7 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 		}
 		
 		if("phix".equalsIgnoreCase(refPath)) {
-			refPath=Data.findPath("?phix174_ill.ref.fa.gz");
+			refPath=Data.findPath("?phix2.fa.gz");
 		}
 		
 		//Do input file # replacement
@@ -249,17 +249,18 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 	public void process(Timer t){
 		
 		final int oldThreads=Shared.threads();
-		Shared.capThreads(allKmers ? 64 : 64);
+		Shared.capThreads(kmersPerRead>0 ? 64 : 64);
 		
 		barcodeStats=loadBarcodes(expectedBarcodes);
 		//Reset counters
 		readsProcessed=0;
 		basesProcessed=0;
 		
-		mapper=(refPath==null ? null : new MicroAligner(31, minIdentity, refPath));
+		MicroIndex3 index=(refPath==null ? null : new MicroIndex3(alignK, 0, refPath, false));
+		mapper=(index==null ? null : new MicroAligner3(index, minIdentity));
 
 		if(dumpIn==null){
-			flowcell=new FlowCell();
+			flowcell=new FlowCell(k);
 			if(loadKmers){loadKmers();}
 			fillTiles();
 			keySets=null;
@@ -269,7 +270,7 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 			flowcell=new FlowCell(dumpIn);
 			
 			if(flowcell.avgReads<targetAverageReads){
-				flowcell=flowcell.widen(targetAverageReads);
+				flowcell=flowcell.widenToTargetReads(targetAverageReads);
 			}
 		}
 		
@@ -282,7 +283,7 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 		outstream.print("Loading kmers:  \t");
 		if(bloomMode) {
 			BloomFilter.printMem=false;
-			KmerCountAbstract.PICK_ONLY_ONE_KMER=!allKmers;
+			KmerCountAbstract.KMERS_PER_READ=kmersPerRead;
 		}
 		if(bloomMode && multithreadedLoad) {
 			KmerCountAbstract.CANONICAL=true;
@@ -321,8 +322,8 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 //			System.err.println("Cells Used:     \t"+bloomFilter.filter.cellsUsed());
 			assert(keySets==null);
 			BloomFilter.printMem=true;
-			KmerCountAbstract.PICK_ONLY_ONE_KMER=false;
 		}
+		KmerCountAbstract.KMERS_PER_READ=0;
 	}
 	
 	BarcodeStats loadBarcodes(String expectedBarcodesFile) {
@@ -335,8 +336,9 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 			bs.length1=ffin1.barcodeLength(1);
 			bs.length2=ffin1.barcodeLength(2);
 		}
-		if(expectedBarcodesFile!=null) {bs.loadBarcodeList(expectedBarcodesFile, 
-				barcodesPerRead>1 ? delimiter : 0, false, false);}
+		if(expectedBarcodesFile!=null) {
+			bs.loadBarcodeList(expectedBarcodesFile, barcodesPerRead>1 ? delimiter : 0, false, false);
+		}
 		return bs;
 	}
 
@@ -368,7 +370,7 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 		
 		ArrayList<MicroTile> mtList=flowcell.calcStats();
 		if(flowcell.avgReads<targetAverageReads){
-			flowcell=flowcell.widen(targetAverageReads);
+			flowcell=flowcell.widenToTargetReads(targetAverageReads);
 			mtList=flowcell.toList();
 		}
 		
@@ -452,7 +454,7 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 	private void loadKmers(Read r, LongList kmers) {
 		if(r==null || r.length()<k) {return;}
 //		if(!randy.nextBoolean()) {return;}//Speed optimization, I guess
-		if(allKmers) {
+		if(kmersPerRead<1) {
 			kmers.clear();
 			BloomFilter.toKmers(r, kmers, k, 0, 0, true);
 			if(keySets!=null) {
@@ -530,9 +532,8 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 					if(barcodeStats!=null) {
 						String code=r1.barcode(true);
 						int hdist=barcodeStats.calcHdist(code);
+						mt.barcodes+=barcodesPerRead;
 						mt.barcodeHDistSum+=hdist;
-						int capped=Tools.min(hdist, mt.barcodeHDist.length-1);
-						mt.barcodeHDist[capped]++;
 					}
 
 					mt.add(r1);
@@ -558,7 +559,7 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 	void processTileKmers(Read r, MicroTile mt, LongList kmers, IntList counts) {
 		if(r==null || r.length()<k) {return;}
 		
-		if(allKmers && bloomMode) {
+		if(kmersPerRead<1 && bloomMode) {
 			processAllKmers(r, mt, kmers, counts);
 		}else {
 			processOneKmer(r, mt);
@@ -572,10 +573,10 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 			mt.misses++;
 			return;
 		}
-		final long key=(allKmers ? Tools.max(kmer, AminoAcid.reverseComplementBinaryFast(kmer, k)) : kmer);
+		final long key=(kmersPerRead<1 ? Tools.max(kmer, AminoAcid.reverseComplementBinaryFast(kmer, k)) : kmer);
 		final int value=(keySets==null ? bloomFilter.getCount(key) : keySets[(int)(key%WAYS)].getValue(key));
 		mt.depthSum+=value;
-		final int cutoff=(allKmers ? 2 : 1);
+		final int cutoff=(kmersPerRead<1 ? 2 : 1);
 		if(value>=cutoff) {mt.hits++;}
 		else {mt.misses++;}
 	}
@@ -599,155 +600,6 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 		mt.kmerReadErrorCount+=(possibleErrors>0 ? 1 : 0);
 	}
 	
-	/*--------------------------------------------------------------*/
-	/*----------------          Alignment           ----------------*/
-	/*--------------------------------------------------------------*/
-	
-//	static void map(Read r, LongHashMap map, byte[] ref, float minIdentity, ByteBuilder buffer) {
-//		if(r==null || r.length()<k || r.match!=null || r.samline!=null) {return;}
-//		byte[] bases=r.bases;
-//		if(bases==null || bases.length<k){return;}
-//		final int bitsPerBase=2;
-//		final int shift=bitsPerBase*k;
-//		final int shift2=shift-bitsPerBase;
-//		final long mask=(shift>63 ? -1L : ~((-1L)<<shift));
-//		
-//		long kmer=0;
-//		long rkmer=0;
-//		int len=0;
-//		int offset=-1;
-//		int orientation=-1;
-//		int ivalue=-1;
-//		int vvalue=-1;
-//		
-//		//TODO: This loop could be replaced by the kmer list which already exists.
-//		for(int i=0; i<bases.length && orientation<0; i++){
-//			final byte b=bases[i];
-//			long x=AminoAcid.baseToNumber[b];
-//			long x2=AminoAcid.baseToComplementNumber[b];
-//			kmer=((kmer<<2)|x)&mask;
-//			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
-//
-//			if(x<0){
-//				len=0;
-//				kmer=rkmer=0;
-//			}else{
-//				len++;
-//				if(len>=k /*&& ((i&1)==0)*/){
-//					long key=Tools.max(kmer, rkmer);
-//					int value=map.get(key);
-//					if(value>=0) {
-//						ivalue=i;
-//						vvalue=value;
-//						
-//						if(value>=1000000000) {
-//							value-=1000000000;
-//							if(key==kmer) {
-//								orientation=1;
-//								offset=value-k2-(bases.length-i-1);
-//							}else {
-//								assert(key==rkmer);
-//								orientation=2;
-//								offset=value-i;
-//							}
-//						}else {
-//							if(key==kmer) {
-//								orientation=0;
-//								offset=value-i;
-//							}else {
-//								assert(key==rkmer);
-//								orientation=3;
-//								offset=value-k2-(bases.length-i-1);
-//							}
-//						}
-//					}
-//				}
-//			}
-//		}
-//		if(orientation<0) {return;}
-//		//				System.err.println("i="+ivalue+", v="+vvalue+
-//		//						", offset="+offset+", orientation="+orientation);
-//		int pad=5;
-//		if(orientation==1 || orientation==3) {
-//			r.reverseComplement();
-//			align(r, ref, offset, offset+r.length(), pad, minIdentity, buffer);
-//			r.reverseComplement();
-//		}else {
-//			align(r, ref, offset, offset+r.length(), pad, minIdentity, buffer);
-//		}
-//	}
-//	
-//	static void align(Read r, byte[] ref, int a, int b, int pad, float minIdentity, ByteBuilder buffer){
-//		int subs=quickAlign(r, ref, a, buffer);
-//		if(subs<4) {
-////			assert(r.match!=null);
-//			return;
-//		}
-//		
-//		SingleStateAlignerFlat2 ssa=GeneCaller.getSSA();
-//		a=Tools.max(0, a-pad);
-//		b=Tools.min(ref.length-1, b+pad);
-//		int[] max=ssa.fillUnlimited(r.bases, ref, a, b, 0);
-//		if(max==null){return;}
-//		
-//		final int rows=max[0];
-//		final int maxCol=max[1];
-//		final int maxState=max[2];
-//		
-//		//returns {score, bestRefStart, bestRefStop} 
-//		//padded: {score, bestRefStart, bestRefStop, padLeft, padRight};
-//		int[] score=ssa.score(r.bases, ref, a, b, rows, maxCol, maxState);
-//		int rstart=score[1];
-//		int rstop=score[2];
-//		r.start=rstart;
-//		r.stop=rstop;
-//		
-//		byte[] match=ssa.traceback(r.bases, ref, a, b, rows, maxCol, maxState);
-//		float id=Read.identity(match);
-//		
-////		if(r.numericID>10000 && r.numericID<10200) {System.err.println(id+"\n"+new String(match));}
-//		
-//		if(id<minIdentity) {return;}//Probably not phix
-//		r.match=match;
-//		
-////		synchronized(System.err) {
-////			System.err.println(r.strand());
-////			System.err.println(new String(ref, a, r.length()));
-////			System.err.println(new String(r.bases));
-////			System.err.println(new String(r.match));
-////			throw new RuntimeException();
-////		}
-//		
-////		float id=Read.identity(match);
-////		return id;
-//	}
-//	
-//	static int quickAlign(Read read, byte[] ref, int a, ByteBuilder buffer) {
-//		byte[] bases=read.bases;
-//		buffer.clear();
-//		int subs=0, ns=0;
-//		for(int i=0, j=a; i<bases.length; i++, j++) {
-//			if(j<0 || j>=ref.length) {
-//				buffer.append('C');
-//			}else {
-//				final byte q=bases[i], r=ref[j];
-//				if(q=='N') {
-//					buffer.append('N');
-//					ns++;
-//				}else if(r=='N' || r==q) {
-//					buffer.append('m');
-//				}else {
-//					buffer.append('S');
-//					subs++;
-//				}
-//			}
-//		}
-//		if(subs<4) {
-//			read.match=buffer.toBytes();
-//		}
-//		return subs;
-//	}
-	
 	/*--------------------------------------------------------------*/
 	/*----------------          Threading           ----------------*/
 	/*--------------------------------------------------------------*/
@@ -795,7 +647,7 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 		WorkerThread(ConcurrentReadInputStream cris_, int tid_){
 			cris=cris_;
 			tid=tid_;
-			fc=new FlowCell();
+			fc=new FlowCell(k);
 		}
 		
 		//Called by start()
@@ -888,9 +740,8 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 			if(barcodeStats!=null) {
 				String code=r1.barcode(true);
 				int hdist=barcodeStats.calcHdist(code);
+				mt.barcodes+=barcodesPerRead;
 				mt.barcodeHDistSum+=hdist;
-				int capped=Tools.min(hdist, mt.barcodeHDist.length-1);
-				mt.barcodeHDist[capped]++;
 			}
 			
 			mt.add(r1);
@@ -979,7 +830,7 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 	private boolean multithreadedFill=false;
 
 	private boolean loadKmers=true;
-	private boolean allKmers=false;
+	private int kmersPerRead=1;
 	private int cbits=4;
 	private int hashes=3;
 	
@@ -994,8 +845,9 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 	private String refPath="phix";
 //	private byte[] ref;
 //	private LongHashMap refIndex;
-	private MicroAligner mapper;
-	float minIdentity=0.7f;
+	private MicroAligner3 mapper;
+	float minIdentity=0.65f;
+	int alignK=19; //Phix is unique down to k=13
 	
 	
 	private byte delimiter='+';
@@ -1030,7 +882,7 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	
