@@ -6,7 +6,6 @@ import java.io.InputStream;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Locale;
 
 import dna.AminoAcid;
 import dna.FastaToChromArrays2;
@@ -841,9 +840,9 @@ public final class AssemblyStats2 {
 			double invbins=1.0/(gcbins==0 ? 1 : gcbins);
 //			assert(false) : Arrays.toString(gchistArray);
 			StringBuilder sb=new StringBuilder();
-			sb.append(String.format(Locale.ROOT, "#GC\tscaffolds\tfraction\tlength\tlen_fraction\n"));
+			sb.append(Tools.format("#GC\tscaffolds\tfraction\tlength\tlen_fraction\n"));
 			for(int i=0; i<gcbins; i++){
-				sb.append(String.format(Locale.ROOT, "%."+gchistDecimals1+"f\t%d\t%.5f\t%d\t%.5f\n",
+				sb.append(Tools.format("%."+gchistDecimals1+"f\t%d\t%.5f\t%d\t%.5f\n",
 						i*invbins, gchistArray_downsampled[i], gchistArray_downsampled[i]*invsum, gchist_by_base_downsampled[i], gchist_by_base_downsampled[i]*invsumbb));
 			}
 			if(gchistFile.equalsIgnoreCase("stdout")){
@@ -861,8 +860,8 @@ public final class AssemblyStats2 {
 		if(bytes<1){bytes=LIMSUM;}
 		double mbps1=bytes*1000d/t.elapsed;
 		double mbps2=sum*1000d/t.elapsed;
-		outstream.println(String.format(Locale.ROOT, "Raw Speed:         \t%.2f MBytes/s",mbps1));
-		outstream.println(String.format(Locale.ROOT, "Uncompressed Speed:\t%.2f MBytes/s",mbps2));
+		outstream.println(Tools.format("Raw Speed:         \t%.2f MBytes/s",mbps1));
+		outstream.println(Tools.format("Uncompressed Speed:\t%.2f MBytes/s",mbps2));
 	}
 	
 	public static double calcLogSumContigs(LongList clist, LongList llist, int cutoff, double base){
@@ -1088,11 +1087,11 @@ public final class AssemblyStats2 {
 		
 		if(FORMAT==0){
 		}else if(FORMAT==1){
-			sb.append("Main genome scaffold sequence total:\t"+String.format(Locale.ROOT, "%.3f MB",scaflen/1000000f)+"\n");
-			sb.append("Main genome contig sequence total:  \t"+String.format(Locale.ROOT, "%.3f MB  \t%.3f%% gap",contiglen/1000000f,(scaflen-contiglen)*100f/scaflen)+"\n");
+			sb.append("Main genome scaffold sequence total:\t"+Tools.format("%.3f MB",scaflen/1000000f)+"\n");
+			sb.append("Main genome contig sequence total:  \t"+Tools.format("%.3f MB  \t%.3f%% gap",contiglen/1000000f,(scaflen-contiglen)*100f/scaflen)+"\n");
 		}else if(FORMAT==2){
 			sb.append("Main genome scaffold sequence total:\t"+scaflen+"\n");
-			sb.append("Main genome contig sequence total:  \t"+String.format(Locale.ROOT, "%d  \t%.3f%% gap",contiglen,(scaflen-contiglen)*100f/scaflen)+"\n");
+			sb.append("Main genome contig sequence total:  \t"+Tools.format("%d  \t%.3f%% gap",contiglen,(scaflen-contiglen)*100f/scaflen)+"\n");
 		}else if(FORMAT==3 || FORMAT==6){
 			
 		}else if(FORMAT==4){
@@ -1102,7 +1101,7 @@ public final class AssemblyStats2 {
 		}else if(FORMAT==8){
 			
 		}else if(FORMAT==7){
-			sb.append("Main genome contig sequence total:  \t"+String.format(Locale.ROOT, "%.3f MB",contiglen/1000000f)+"\n");
+			sb.append("Main genome contig sequence total:  \t"+Tools.format("%.3f MB",contiglen/1000000f)+"\n");
 		}else{throw new RuntimeException("Unknown format");}
 		
 		if(FORMAT<3){
@@ -1422,7 +1421,7 @@ public final class AssemblyStats2 {
 				sb.append("Number of bases in scaffolds>50 KB: \t"+basesOver50+"\n");
 			}
 			
-			sb.append("% main genome in scaffolds > 50 KB: \t"+String.format(Locale.ROOT, "%.2f%%", fractionOver50)+"\n");
+			sb.append("% main genome in scaffolds > 50 KB: \t"+Tools.format("%.2f%%", fractionOver50)+"\n");
 			if(printheadersize){sb.append("Header:\t"+formatKB(HEADERLENSUM, 3, 0)+(HEADERLENSUM<1000 ? " bytes" : ""));}
 			
 			//		System.out.println();
@@ -1496,8 +1495,8 @@ public final class AssemblyStats2 {
 			sb.append(scaffolds+"\t");
 			sb.append(contigs+"\t");
 			sb.append(scaflen+"\t");
-			sb.append(String.format(Locale.ROOT, "%d",contiglen)+"\t");
-			sb.append(String.format(Locale.ROOT, "%.3f",(scaflen-contiglen)*100f/scaflen)+"\t");
+			sb.append(Tools.format("%d",contiglen)+"\t");
+			sb.append(Tools.format("%.3f",(scaflen-contiglen)*100f/scaflen)+"\t");
 			sb.append(ll50+"\t");
 			sb.append(formatKB(ln50, 3, 0)+"\t");
 			sb.append(cl50+"\t");
@@ -1523,9 +1522,9 @@ public final class AssemblyStats2 {
 			if(printExtended){
 				sb.append(basesOver50+"\t");
 			}
-			sb.append(String.format(Locale.ROOT, "%.3f", fractionOver50)+"\t");
-			sb.append(String.format(Locale.ROOT, "%.5f", (counts[1]+counts[2])*1.0/(counts[0]+counts[1]+counts[2]+counts[3]))+"\t");
-			sb.append(String.format(Locale.ROOT, "%.5f", gc_std));
+			sb.append(Tools.format("%.3f", fractionOver50)+"\t");
+			sb.append(Tools.format("%.5f", (counts[1]+counts[2])*1.0/(counts[0]+counts[1]+counts[2]+counts[3]))+"\t");
+			sb.append(Tools.format("%.5f", gc_std));
 			if(addfilename){sb.append('\t').append(name);}
 			
 			tsw.println(sb);
@@ -1606,8 +1605,8 @@ public final class AssemblyStats2 {
 			sb.append(scaffolds+"\t");
 //			sb.append(contigs+"\t");
 			sb.append(scaflen+"\t");
-//			sb.append(String.format(Locale.ROOT, "%d",contiglen)+"\t");
-//			sb.append(String.format(Locale.ROOT, "%.3f",(scaflen-contiglen)*100f/scaflen)+"\t");
+//			sb.append(Tools.format("%d",contiglen)+"\t");
+//			sb.append(Tools.format("%.3f",(scaflen-contiglen)*100f/scaflen)+"\t");
 			sb.append(ll50+"\t");
 			sb.append(formatKB(ln50, 3, 0)+"\t");
 			if(printL90){
@@ -1630,10 +1629,10 @@ public final class AssemblyStats2 {
 			if(printExtended){
 				sb.append('\t').append(basesOver50);
 			}
-			sb.append(String.format(Locale.ROOT, "\t%.3f", fractionOver50));
+			sb.append(Tools.format("\t%.3f", fractionOver50));
 
-			sb.append(String.format(Locale.ROOT, "\t%.5f", (counts[1]+counts[2])*1.0/(counts[0]+counts[1]+counts[2]+counts[3]))+"\t");
-			sb.append(String.format(Locale.ROOT, "\t%.5f", gc_std));
+			sb.append(Tools.format("\t%.5f", (counts[1]+counts[2])*1.0/(counts[0]+counts[1]+counts[2]+counts[3]))+"\t");
+			sb.append(Tools.format("\t%.5f", gc_std));
 			
 			if(addfilename){sb.append('\t').append(name);}
 			tsw.println(sb);
@@ -1676,8 +1675,8 @@ public final class AssemblyStats2 {
 //			sb.append(scaffolds+"\t");
 			sb.append(contigs+"\t");
 //			sb.append(scaflen+"\t");
-			sb.append(String.format(Locale.ROOT, "%d",contiglen)+"\t");
-			sb.append(String.format(Locale.ROOT, "%.3f",(scaflen-contiglen)*100f/scaflen)+"\t");
+			sb.append(Tools.format("%d",contiglen)+"\t");
+			sb.append(Tools.format("%.3f",(scaflen-contiglen)*100f/scaflen)+"\t");
 //			sb.append(ll50+"\t");
 //			sb.append(formatKB(ln50, 3, 0)+"\t");
 			sb.append(cl50+"\t");
@@ -1696,9 +1695,9 @@ public final class AssemblyStats2 {
 //			sb.append(formatKB(maxScaf, 3, 0)+"\t");
 			sb.append(formatKB(maxContig, 3, 0)+"\t");
 //			sb.append(numOver50+"\t");
-//			sb.append(String.format(Locale.ROOT, "%.3f", fractionOver50)+"\t");
-			sb.append(String.format(Locale.ROOT, "%.5f", (counts[1]+counts[2])*1.0/(counts[0]+counts[1]+counts[2]+counts[3]))+"\t");
-			sb.append(String.format(Locale.ROOT, "%.5f", gc_std));
+//			sb.append(Tools.format("%.3f", fractionOver50)+"\t");
+			sb.append(Tools.format("%.5f", (counts[1]+counts[2])*1.0/(counts[0]+counts[1]+counts[2]+counts[3]))+"\t");
+			sb.append(Tools.format("%.5f", gc_std));
 			if(addfilename){sb.append('\t').append(name);}
 			tsw.println(sb);
 		}else if(FORMAT==7){
@@ -1713,7 +1712,7 @@ public final class AssemblyStats2 {
 			}
 			sb.append("Max contig length:                  \t"+formatKB(maxContig, 3, 0)+"\n");
 			sb.append("Number of contigs > 1 KB:           \t"+numOver50+"\n");
-			sb.append("% main genome in contigs > 1 KB:    \t"+String.format(Locale.ROOT, "%.2f%%", fractionOver50)+"\n");
+			sb.append("% main genome in contigs > 1 KB:    \t"+Tools.format("%.2f%%", fractionOver50)+"\n");
 			if(printheadersize){sb.append("Header:\t"+formatKB(HEADERLENSUM, 3, 0)+(HEADERLENSUM<1000 ? " bytes" : ""));}
 			
 			if(GCFORMAT==0){
@@ -1739,8 +1738,8 @@ public final class AssemblyStats2 {
 			if(bytes<1){bytes=LIMSUM;}
 			double mbps=bytes*1000d/t.elapsed;
 			double mbpps=shared.Vector.sum(counts)*1000d/t.elapsed;
-			outstream.println(String.format(Locale.ROOT, "Speed:\t%.2f MBytes/s",mbps));
-			outstream.println(String.format(Locale.ROOT, "      \t%.2f MBases/s",mbpps));
+			outstream.println(Tools.format("Speed:\t%.2f MBytes/s",mbps));
+			outstream.println(Tools.format("      \t%.2f MBases/s",mbpps));
 		}
 		
 		if(bbmapkmer>0){
@@ -1881,17 +1880,17 @@ public final class AssemblyStats2 {
 		if(iupac>0 && iupacD<0.0001){iupacD=0.0001;}
 		if(other>0 && otherD<0.0001){otherD=0.0001;}
 		if(GCFORMAT==0 || GCFORMAT==1){
-			return sb.append(String.format(Locale.ROOT, "\t%d\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\n",
+			return sb.append(Tools.format("\t%d\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\n",
 					sumAll, a*invDef, c*invDef, g*invDef, t*invDef, n*invAll, iupacD, otherD, (g+c)*invDef)).toString();
 		}else if(GCFORMAT==2){
-			return sb.append(String.format(Locale.ROOT, "\t%.4f\n", (g+c)*invDef)).toString();
+			return sb.append(Tools.format("\t%.4f\n", (g+c)*invDef)).toString();
 		}else if(GCFORMAT==3){
-			return sb.append(String.format(Locale.ROOT, "\t%d\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\n",
+			return sb.append(Tools.format("\t%d\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\n",
 					sumAll, a*invDef, c*invDef, g*invDef, t*invDef, n*invAll, iupacD, otherD, (g+c)*invDef)).toString();
 		}else if(GCFORMAT==4){
-			return sb.append(String.format(Locale.ROOT, "\t%d\t%.4f\n", sumAll, (g+c)*invDef)).toString();
+			return sb.append(Tools.format("\t%d\t%.4f\n", sumAll, (g+c)*invDef)).toString();
 		}else if(GCFORMAT==5){
-			return sb.append(String.format(Locale.ROOT, "\t%d\t%.4f\t%.2f\t%.2f\n", sumAll, (g+c)*invDef, logsum(sumAll), powersum(sumAll))).toString();
+			return sb.append(Tools.format("\t%d\t%.4f\t%.2f\t%.2f\n", sumAll, (g+c)*invDef, logsum(sumAll), powersum(sumAll))).toString();
 		}else{
 			throw new RuntimeException("Unknown format.");
 		}
@@ -1907,17 +1906,17 @@ public final class AssemblyStats2 {
 		if(iupac>0 && iupacD<0.0001){iupacD=0.0001;}
 		if(other>0 && otherD<0.0001){otherD=0.0001;}
 		if(FORMAT==7){
-			return sb.append(String.format(Locale.ROOT, "%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\n",
+			return sb.append(Tools.format("%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\n",
 					a*invDef, c*invDef, g*invDef, t*invDef, (g+c)*invDef, gc_std)).toString();
 		}else if(GCFORMAT==0 || GCFORMAT==1 || GCFORMAT==3 || GCFORMAT==4 || GCFORMAT==5){
 			if(GC_FRACTION){
-			return sb.append(String.format(Locale.ROOT, "%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\n",
+			return sb.append(Tools.format("%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\n",
 					a*invDef, c*invDef, g*invDef, t*invDef, n*invAll, iupacD, otherD, (g+c)*invDef, gc_std)).toString();
 			}
-			return sb.append(String.format(Locale.ROOT, "%d\t%d\t%d\t%d\t%d\t%d\t%d\t%.4f\t%.4f\n",
+			return sb.append(Tools.format("%d\t%d\t%d\t%d\t%d\t%d\t%d\t%.4f\t%.4f\n",
 					a, c, g, t, n, iupac, other, (g+c)*invDef, gc_std)).toString();
 		}else if(GCFORMAT==2){
-			return sb.append(String.format(Locale.ROOT, "%.4f\t%.4f\n", (g+c)*invDef, gc_std)).toString();
+			return sb.append(Tools.format("%.4f\t%.4f\n", (g+c)*invDef, gc_std)).toString();
 		}else{
 			throw new RuntimeException("Unknown format.");
 		}
@@ -1947,11 +1946,11 @@ public final class AssemblyStats2 {
 		if(FORMAT>=2 || x<1000){
 			s=Long.toString(x);
 		}else if(x<1000000){
-			s=String.format(Locale.ROOT, "%."+precision+"f",x/1000f);
+			s=Tools.format("%."+precision+"f",x/1000f);
 			while(s.contains(".") && (s.endsWith("0") || s.endsWith("."))){s=s.substring(0, s.length()-1);}
 			s=s+" KB";
 		}else{
-			s=String.format(Locale.ROOT, "%."+precision+"f",x/1000000f);
+			s=Tools.format("%."+precision+"f",x/1000000f);
 			while(s.contains(".") && (s.endsWith("0") || s.endsWith("."))){s=s.substring(0, s.length()-1);}
 			s=s+" MB";
 		}
@@ -1966,11 +1965,11 @@ public final class AssemblyStats2 {
 		else if(FORMAT>=2 || x<1000){
 			s=Long.toString(x);
 		}else if(x<1000000){
-			s=String.format(Locale.ROOT, "%."+precision+"f",x/1000f);
+			s=Tools.format("%."+precision+"f",x/1000f);
 			while(s.contains(".") && (s.endsWith("0") || s.endsWith("."))){s=s.substring(0, s.length()-1);}
 			s=s+" KB";
 		}else{
-			s=String.format(Locale.ROOT, "%."+precision+"f",x/1000000f);
+			s=Tools.format("%."+precision+"f",x/1000000f);
 			while(s.contains(".") && (s.endsWith("0") || s.endsWith("."))){s=s.substring(0, s.length()-1);}
 			s=s+" MB";
 		}
@@ -2003,7 +2002,7 @@ public final class AssemblyStats2 {
 	}
 	
 	private static final String formatPercent(float x){
-		String s=String.format(Locale.ROOT, "%.2f%%", x);
+		String s=Tools.format("%.2f%%", x);
 		while(s.length()<8){s=" "+s;}
 		return s;
 	}
@@ -2074,7 +2073,7 @@ public final class AssemblyStats2 {
 	private static long HEADERLENSUM=0;
 	
 	private static int bbmapkmer=0;//13;
-	public static boolean overwrite=false;
+	public static boolean overwrite=true;
 	public static boolean append=false;
 	public static boolean useheader=true;
 	public static boolean addfilename=false;
