@@ -1,7 +1,6 @@
 package jgi;
 
 import java.util.Arrays;
-import java.util.Locale;
 
 import assemble.Tadpole;
 import assemble.Tadpole1;
@@ -269,16 +268,16 @@ public final class BBMergeOverlapper {
 //			sb.append("_blen=").append(b.length()*0.01f, 2);
 //			sb.append("_bi=").append(bestInsert*.01f, 2);
 //			sb.append("_bo=").append(bestOverlap*0.1f, 1);
-//			sb.append("_bb=").append(String.format(Locale.ROOT, "%.4f", bestBad*.1f));
-//			sb.append("_bg=").append(String.format(Locale.ROOT, "%.4f", bestGood*.1f));
-//			sb.append("_br=").append(String.format(Locale.ROOT, "%.4f", bestRatio));
+//			sb.append("_bb=").append(Tools.format("%.4f", bestBad*.1f));
+//			sb.append("_bg=").append(Tools.format("%.4f", bestGood*.1f));
+//			sb.append("_br=").append(Tools.format("%.4f", bestRatio));
 //			sb.append("_bbi=").append(bestBadInt*.1f, 1);
 //
 //			sb.append("_sbi=").append(secondBestInsert*.01f, 2);
 //			sb.append("_sbo=").append(secondBestOverlap*0.1f, 1);
-//			sb.append("_sbb=").append(String.format(Locale.ROOT, "%.4f", secondBestBad*.1f));
-//			sb.append("_sbg=").append(String.format(Locale.ROOT, "%.4f", secondBestGood*.1f));
-//			sb.append("_sbr=").append(String.format(Locale.ROOT, "%.4f", secondBestRatio));
+//			sb.append("_sbb=").append(Tools.format("%.4f", secondBestBad*.1f));
+//			sb.append("_sbg=").append(Tools.format("%.4f", secondBestGood*.1f));
+//			sb.append("_sbr=").append(Tools.format("%.4f", secondBestRatio));
 //			sb.append("_sbbi=").append(secondBestBadInt*.1f, 1);
 //			sb.append("_rr=").append(secondBestRatio/bestRatio, 4);
 //			sb.append("_badr=").append(secondBestBad/bestBad, 4);
