@@ -6,7 +6,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
 import java.util.HashMap;
-import java.util.Locale;
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
@@ -702,21 +701,21 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 				}
 				
 //				{
-//					tsw.print(String.format(Locale.ROOT, "%s\t%d\t", args));
+//					tsw.print(Tools.format("%s\t%d\t", args));
 //				}
 				
 				sb.append(orf.name).append('\t');
 				sb.append(orf.length()).append('\t');
 				sb.append(orf.baseDepth).append('\t');
-				sb.append(String.format(Locale.ROOT, "%.4f", orf.avgCoverage())).append('\t');
+				sb.append(Tools.format("%.4f", orf.avgCoverage())).append('\t');
 				sb.append(orf.avgCoverage()/mappedNonClippedBases);
 
 				sb.append('\t');
 				sb.append(orf.minDepth).append('\t');
 				sb.append(orf.maxDepth).append('\t');
 				sb.append(orf.medianDepth).append('\t');
-				sb.append(String.format(Locale.ROOT, "%.4f",orf.stdevDepth)).append('\t');
-				sb.append(String.format(Locale.ROOT, "%.4f",orf.fractionCovered()));
+				sb.append(Tools.format("%.4f",orf.stdevDepth)).append('\t');
+				sb.append(Tools.format("%.4f",orf.fractionCovered()));
 
 				sb.append('\n');
 				tsw.print(sb.toString());
@@ -861,23 +860,23 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 				String kcorrectS="Percent correct "+k+"-mers:";
 				while(kcovS.length()<26){kcovS=kcovS+" ";}
 				while(kcovS.length()<26){kcorrectS=kcorrectS+" ";}
-				outstream.println(String.format(Locale.ROOT, "\n"+kcovS+"           \t%.3f", mappedKmers*1.0/refKmers));
-				outstream.println(String.format(Locale.ROOT, kcorrectS+"           \t%.3f", 100*correctKmers/kmersProcessed));
+				outstream.println(Tools.format("\n"+kcovS+"           \t%.3f", mappedKmers*1.0/refKmers));
+				outstream.println(Tools.format(kcorrectS+"           \t%.3f", 100*correctKmers/kmersProcessed));
 				//			outstream.println(kmersProcessed+", "+correctKmers);
 			}
 			
-			outstream.println(String.format(Locale.ROOT, "\nPercent mapped:                      \t%.3f", mappedReads*100f/readsProcessed));
-			outstream.println(String.format(Locale.ROOT, "Percent proper pairs:                \t%.3f", properPairs*100f/readsProcessed));
+			outstream.println(Tools.format("\nPercent mapped:                      \t%.3f", mappedReads*100f/readsProcessed));
+			outstream.println(Tools.format("Percent proper pairs:                \t%.3f", properPairs*100f/readsProcessed));
 //			outstream.println(depthCovered);
-			outstream.println(String.format(Locale.ROOT, "Average coverage:                    \t%.3f", depthCovered2));
-			outstream.println(String.format(Locale.ROOT, "Average coverage with deletions:     \t%.3f", depthCovered3));
+			outstream.println(Tools.format("Average coverage:                    \t%.3f", depthCovered2));
+			outstream.println(Tools.format("Average coverage with deletions:     \t%.3f", depthCovered3));
 			if(USE_COVERAGE_ARRAYS && calcCovStdev){
 				double[] stdev=sdTool.standardDeviation(list, minscaf);
-				outstream.println(String.format(Locale.ROOT, "Standard deviation:                    \t%.3f", stdev[1]));
+				outstream.println(Tools.format("Standard deviation:                    \t%.3f", stdev[1]));
 			}
-			outstream.println(String.format(Locale.ROOT, "Percent scaffolds with any coverage: \t%.2f", pctScaffoldsWithCoverage));
+			outstream.println(Tools.format("Percent scaffolds with any coverage: \t%.2f", pctScaffoldsWithCoverage));
 			if(USE_COVERAGE_ARRAYS || USE_BITSETS){
-				outstream.println(String.format(Locale.ROOT, "Percent of reference bases covered:  \t%.2f", pctCovered));
+				outstream.println(Tools.format("Percent of reference bases covered:  \t%.2f", pctCovered));
 			}
 		}else{
 			outstream.println("reads="+readsProcessed);
@@ -886,16 +885,16 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 			outstream.println("mappedBasesWithDels="+mappedBasesWithDels);
 			outstream.println("refScaffolds="+totalScaffolds);
 			outstream.println("refBases="+refBases);
-			outstream.println(String.format(Locale.ROOT, "percentMapped=%.3f", mappedReads*100f/readsProcessed));
-			outstream.println(String.format(Locale.ROOT, "percentPaired=%.3f", properPairs*100f/readsProcessed));
-			outstream.println(String.format(Locale.ROOT, "averageCoverage=%.3f", depthCovered2));
+			outstream.println(Tools.format("percentMapped=%.3f", mappedReads*100f/readsProcessed));
+			outstream.println(Tools.format("percentPaired=%.3f", properPairs*100f/readsProcessed));
+			outstream.println(Tools.format("averageCoverage=%.3f", depthCovered2));
 			if(USE_COVERAGE_ARRAYS && calcCovStdev){
 				double[] stdev=sdTool.standardDeviation(list, minscaf);
-				outstream.println(String.format(Locale.ROOT, "standardDeviation=%.3f", stdev[1]));
+				outstream.println(Tools.format("standardDeviation=%.3f", stdev[1]));
 			}
-			outstream.println(String.format(Locale.ROOT, "percentCoveredScaffolds=%.2f", pctScaffoldsWithCoverage));
+			outstream.println(Tools.format("percentCoveredScaffolds=%.2f", pctScaffoldsWithCoverage));
 			if(USE_COVERAGE_ARRAYS || USE_BITSETS){
-				outstream.println(String.format(Locale.ROOT, "percentCoveredBases=%.2f", pctCovered));
+				outstream.println(Tools.format("percentCoveredBases=%.2f", pctCovered));
 			}
 		}
 		if(verboseTime) {t.stopAndStart("Calc StdDev:");}
@@ -915,7 +914,7 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 					tsw.println(pound+"ID\tAvg_fold\tLength\tRef_GC\tCovered_percent\tCovered_bases\tPlus_reads\tMinus_reads"+
 							(COUNT_GC ? "\tRead_GC" : "")+
 							(USE_COVERAGE_ARRAYS ? ("\tMedian_fold\tStd_Dev") : "")+
-							(USE_WINDOW ? "\tUnder_"+String.format(Locale.ROOT, "%.0f",LOW_COV_DEPTH)+"/"+LOW_COV_WINDOW : ""));
+							(USE_WINDOW ? "\tUnder_"+Tools.format("%.0f",LOW_COV_DEPTH)+"/"+LOW_COV_WINDOW : ""));
 				}
 			}
 			//Maximally:
@@ -956,7 +955,7 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 				//			pw.print(scaf.name);
 				if(tsw!=null && (sum>0 || !NONZERO_ONLY) && scaf.length>=minscaf){
 					if(TWOCOLUMN){
-//						tsw.print(String.format(Locale.ROOT, "%s\t%.4f\n", scaf.name, sum/(double)scaf.length));
+//						tsw.print(Tools.format("%s\t%.4f\n", scaf.name, sum/(double)scaf.length));
 						tsw.print(scaf.name).tab().print(sum/(double)scaf.length, 4).nl();
 					}else {
 						//Variable portion:
@@ -1119,8 +1118,8 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 				double[] stdev=sdTool.standardDeviation(list, minscaf);
 //				double[] stdev=sdTool.standardDeviationBinned(list, binsize, minscaf);//Singlethreaded
 				if(stdev!=null){
-					tsw.print(pound+"Mean\t"+String.format(Locale.ROOT, "%.3f", stdev[0])+"\n");
-					tsw.print(pound+"STDev\t"+String.format(Locale.ROOT, "%.3f", stdev[1])+"\n");
+					tsw.print(pound+"Mean\t"+Tools.format("%.3f", stdev[0])+"\n");
+					tsw.print(pound+"STDev\t"+Tools.format("%.3f", stdev[1])+"\n");
 				}
 			}
 			tsw.print(pound+"RefName\tCov\tPos\tRunningPos\n");
@@ -1171,8 +1170,8 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 				double[] stdev=sdTool.standardDeviation(list, minscaf);
 //				double[] stdev=sdTool.standardDeviationBinned(list, binsize, minscaf);//Singlethreaded
 				if(stdev!=null){
-					tsw.print(pound+"Mean\t"+String.format(Locale.ROOT, "%.3f", stdev[0])+"\n");
-					tsw.print(pound+"STDev\t"+String.format(Locale.ROOT, "%.3f", stdev[1])+"\n");
+					tsw.print(pound+"Mean\t"+Tools.format("%.3f", stdev[0])+"\n");
+					tsw.print(pound+"STDev\t"+Tools.format("%.3f", stdev[1])+"\n");
 				}
 			}
 			tsw.print(pound+"RefName\tCov\tPos\tRunningPos\n");
@@ -1369,7 +1368,7 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 		for(int bin=1; bin<normalized.length; bin++){
 //			assert((absolute[bin]*invScafs)!=Double.NaN && (normalized[bin]*invScafs)!=Double.NaN) : invScafs+", "+absolute[bin]+", "+normalized[bin];
 //			assert(false) : invScafs+", "+absolute[bin]+", "+normalized[bin]+", "+(absolute[bin]*invScafs)+", "+(normalized[bin]*invScafs);
-			tsw.print(String.format(Locale.ROOT, "%s\t%d\t%.5f\t%.5f\n", "all", bin, absolute[bin]*invScafs, normalized[bin]*normMult));
+			tsw.print(Tools.format("%s\t%d\t%.5f\t%.5f\n", "all", bin, absolute[bin]*invScafs, normalized[bin]*normMult));
 		}
 		
 		tsw.poisonAndWait();
@@ -1396,9 +1395,9 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 		
 		/* Print header */
 		tsw.print("#File\t"+(in1==null ? "" : in1)+"\n");
-		tsw.print(String.format(Locale.ROOT, "#Reads\t%d\n",readsIn));
-		tsw.print(String.format(Locale.ROOT, "#Mapped\t%d\n",mappedReads));
-		tsw.print(String.format(Locale.ROOT, "#RefSequences\t%d\n",list.size()));
+		tsw.print(Tools.format("#Reads\t%d\n",readsIn));
+		tsw.print(Tools.format("#Mapped\t%d\n",mappedReads));
+		tsw.print(Tools.format("#RefSequences\t%d\n",list.size()));
 		tsw.print("#Name\tLength\tBases\tCoverage\tReads\tRPKM\tFrags\tFPKM\n");
 		
 		final float readMult=1000000000f/Tools.max(1, mappedReads);
@@ -1415,7 +1414,7 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 			final double readMult2=readMult*invlen;
 			final double fragMult2=fragMult*invlen;
 			if(reads>0 || !printNonZeroOnly){
-//				tsw.print(String.format(Locale.ROOT, "%s\t%d\t%d\t%.4f\t%d\t%.4f\t%d\t%.4f\n",s,len,bases,bases*invlen,reads,reads*readMult2,frags,frags*fragMult2));
+//				tsw.print(Tools.format("%s\t%d\t%d\t%.4f\t%d\t%.4f\t%d\t%.4f\n",s,len,bases,bases*invlen,reads,reads*readMult2,frags,frags*fragMult2));
 				tsw.print(s).tab().print(len).tab().print(bases).tab();
 				tsw.print(bases*invlen, 4).tab().print(reads).tab().print(reads*readMult2, 4).tab();
 				tsw.print(frags).tab().print(frags*fragMult2, 4).nl();
@@ -1877,7 +1876,7 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 	
 
 	/** Permission to overwrite existing files */
-	public static boolean overwrite=false;
+	public static boolean overwrite=true;
 	/** Permission to append to existing files */
 	public static boolean append=false;
 	/** Print verbose log messages */
