@@ -11,7 +11,6 @@ import static jgi.Dedupe.nmerIndex;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
-import java.util.Locale;
 import java.util.concurrent.ArrayBlockingQueue;
 
 import dna.AminoAcid;
@@ -178,7 +177,7 @@ public class TetramerFrequencies {
 
 		t.stop();
 		outstream.println("Time:                         \t"+t);
-		outstream.println("Reads Processed:    "+readsProcessed+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
+		outstream.println("Reads Processed:    "+readsProcessed+" \t"+Tools.format("%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
 	}
 
 	// TODO: optimize the algorithm ...
@@ -247,7 +246,7 @@ public class TetramerFrequencies {
 		float mult=1f/(line.length()-k+1);
 		for (int cnt: counts){
 			sb.append('\t');
-			sb.append(String.format(Locale.ROOT, "%.4f", cnt*mult));
+			sb.append(Tools.format("%.4f", cnt*mult));
 		}
 		sb.append('\n');
 	}
