@@ -1733,7 +1733,7 @@ public class Trainer implements Accumulator<WorkerThread> {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	
