@@ -3,7 +3,6 @@ package stream;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Locale;
 
 import dna.AminoAcid;
 import dna.ChromosomeArray;
@@ -12,7 +11,6 @@ import dna.Gene;
 import dna.ScafLoc;
 import shared.KillSwitch;
 import shared.LineParser1;
-import shared.LineParser2;
 import shared.Parse;
 import shared.Shared;
 import shared.Tools;
@@ -127,7 +125,7 @@ public class SamLine implements Serializable {
 		int scaflen=0, scafloc=0, scaflen2=0;
 		byte[] name1=bytestar, name2=bytestar;
 		if(r1.mapped()){
-			assert(r1.chrom>=0);
+			assert(r1.chrom>=0) : r1.chrom+", "+r1.start+", "+r1.stop;
 			chrom1=r1.chrom;
 			start1=r1.start;
 			stop1=r1.stop;
@@ -1651,7 +1649,7 @@ public class SamLine implements Serializable {
 	public static String makeIdentityTag(byte[] match, boolean perfect){
 		if(perfect){return "YI:f:100";}
 		float f=Read.identity(match);
-		return String.format(Locale.ROOT, "YI:f:%.2f", (100*f));
+		return Tools.format("YI:f:%.2f", (100*f));
 	}
 	
 	public static String makeScoreTag(int score){
