@@ -79,7 +79,7 @@ public final class LongLongHashMap{
 		Shared.printMemory();
 		Timer t=new Timer();
 		for(int k=0; k<2; k++){
-			System.err.println("LongHashMap:");
+			System.err.println("LongLongHashMap:");
 			t.start();
 			for(int i=0; i<runs; i++){
 //				for(long x : ll.array){
