@@ -1,7 +1,6 @@
 package tracker;
 
 import java.util.Arrays;
-import java.util.Locale;
 
 import dna.AminoAcid;
 import shared.Parse;
@@ -223,8 +222,8 @@ public class EntropyTracker {
 		if(e<=0){e=0;}
 		
 		if(verbose){
-			System.err.println(String.format(Locale.ROOT, "%.3f", eSum)+"\t"+String.format(Locale.ROOT, "%.3f", entropyMult)+"\t"
-					+String.format(Locale.ROOT, "%.3f", e)+"\t"+len+"\t"+unique+"\t"+basesToString());
+			System.err.println(Tools.format("%.3f", eSum)+"\t"+Tools.format("%.3f", entropyMult)+"\t"
+					+Tools.format("%.3f", e)+"\t"+len+"\t"+unique+"\t"+basesToString());
 		}
 		
 		return e;
@@ -253,8 +252,8 @@ public class EntropyTracker {
 		if(e<=0){e=0;}
 		
 		if(verbose){
-			System.err.println(String.format(Locale.ROOT, "%.3f", eSum)+"\t"+String.format(Locale.ROOT, "%.3f", entropyMult)+"\t"
-					+String.format(Locale.ROOT, "%.3f", e)+"\t"+len+"\t"+unique+"\t"+basesToString());
+			System.err.println(Tools.format("%.3f", eSum)+"\t"+Tools.format("%.3f", entropyMult)+"\t"
+					+Tools.format("%.3f", e)+"\t"+len+"\t"+unique+"\t"+basesToString());
 		}
 		
 		return e;
@@ -307,8 +306,8 @@ public class EntropyTracker {
 		if(e<=0){e=0;}
 		
 		if(verbose){
-			System.err.println(String.format(Locale.ROOT, "%.3f", eSum)+"\t"+String.format(Locale.ROOT, "%.3f", entropyMult)+"\t"
-					+String.format(Locale.ROOT, "%.3f", e)+"\t"+len+"\t"+unique+"\t"+basesToString());
+			System.err.println(Tools.format("%.3f", eSum)+"\t"+Tools.format("%.3f", entropyMult)+"\t"
+					+Tools.format("%.3f", e)+"\t"+len+"\t"+unique+"\t"+basesToString());
 		}
 		
 		return e;
